@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals
 
-import re
 import unicodedata
+import warnings
 
 from .compat import map
 from .conv_table import (
@@ -19,7 +19,7 @@ from .conv_table import (
     JULIUS_LONG_VOWEL,
     K2H_TABLE,
     KANA2HEP,
-    SMALL_KANA2BIG_KANA,
+    SMALL_KANA2NORMAL_KANA,
     Z2H_A,
     Z2H_AD,
     Z2H_AK,
@@ -30,7 +30,6 @@ from .conv_table import (
 )
 
 consonants = frozenset('sdfghjklqwrtypzxcvbnm')
-ending_h_pattern = re.compile(r'h$')
 
 
 def _exclude_ignorechar(ignore, conv_map):
@@ -126,6 +125,15 @@ def kata2hira(text, ignore=''):
 
 
 def enlargesmallkana(text, ignore=''):
+    warn_msg = (
+        '`enlargesmallkana` is deprecated and will be removed in future versions.'
+        ' Use `enlarge_smallkana` instead.'
+    )
+    warnings.warn(warn_msg, UserWarning)
+    return enlarge_smallkana(text, ignore)
+
+
+def enlarge_smallkana(text, ignore=''):
     """Convert small Hiragana or Katakana to normal size
 
     Parameters
@@ -147,7 +155,7 @@ def enlargesmallkana(text, ignore=''):
     >>> print(jaconv.enlargesmallkana('キュゥべえ'))
     キユウべえ
     """
-    return _translate(text, ignore, SMALL_KANA2BIG_KANA)
+    return _translate(text, ignore, SMALL_KANA2NORMAL_KANA)
 
 
 def h2z(text, ignore='', kana=True, ascii=False, digit=False):
@@ -184,21 +192,20 @@ def h2z(text, ignore='', kana=True, ascii=False, digit=False):
     """
 
     def _conv_dakuten(text):
-        """Convert Hankaku Dakuten Kana to Zenkaku Dakuten Kana
-        """
-        text = text.replace("ｶﾞ", "ガ").replace("ｷﾞ", "ギ")
-        text = text.replace("ｸﾞ", "グ").replace("ｹﾞ", "ゲ")
-        text = text.replace("ｺﾞ", "ゴ").replace("ｻﾞ", "ザ")
-        text = text.replace("ｼﾞ", "ジ").replace("ｽﾞ", "ズ")
-        text = text.replace("ｾﾞ", "ゼ").replace("ｿﾞ", "ゾ")
-        text = text.replace("ﾀﾞ", "ダ").replace("ﾁﾞ", "ヂ")
-        text = text.replace("ﾂﾞ", "ヅ").replace("ﾃﾞ", "デ")
-        text = text.replace("ﾄﾞ", "ド").replace("ﾊﾞ", "バ")
-        text = text.replace("ﾋﾞ", "ビ").replace("ﾌﾞ", "ブ")
-        text = text.replace("ﾍﾞ", "ベ").replace("ﾎﾞ", "ボ")
-        text = text.replace("ﾊﾟ", "パ").replace("ﾋﾟ", "ピ")
-        text = text.replace("ﾌﾟ", "プ").replace("ﾍﾟ", "ペ")
-        return text.replace("ﾎﾟ", "ポ").replace("ｳﾞ", "ヴ")
+        """Convert Hankaku Dakuten Kana to Zenkaku Dakuten Kana"""
+        text = text.replace('ｶﾞ', 'ガ').replace('ｷﾞ', 'ギ')
+        text = text.replace('ｸﾞ', 'グ').replace('ｹﾞ', 'ゲ')
+        text = text.replace('ｺﾞ', 'ゴ').replace('ｻﾞ', 'ザ')
+        text = text.replace('ｼﾞ', 'ジ').replace('ｽﾞ', 'ズ')
+        text = text.replace('ｾﾞ', 'ゼ').replace('ｿﾞ', 'ゾ')
+        text = text.replace('ﾀﾞ', 'ダ').replace('ﾁﾞ', 'ヂ')
+        text = text.replace('ﾂﾞ', 'ヅ').replace('ﾃﾞ', 'デ')
+        text = text.replace('ﾄﾞ', 'ド').replace('ﾊﾞ', 'バ')
+        text = text.replace('ﾋﾞ', 'ビ').replace('ﾌﾞ', 'ブ')
+        text = text.replace('ﾍﾞ', 'ベ').replace('ﾎﾞ', 'ボ')
+        text = text.replace('ﾊﾟ', 'パ').replace('ﾋﾟ', 'ピ')
+        text = text.replace('ﾌﾟ', 'プ').replace('ﾍﾟ', 'ペ')
+        return text.replace('ﾎﾟ', 'ポ').replace('ｳﾞ', 'ヴ')
 
     if ascii:
         if digit:
@@ -227,6 +234,16 @@ def h2z(text, ignore='', kana=True, ascii=False, digit=False):
     return _convert(text, h2z_map)
 
 
+def hankaku2zenkaku(text, ignore='', kana=True, ascii=False, digit=False):
+    """An alias of h2z"""
+    return h2z(text, ignore, kana, ascii, digit)
+
+
+def han2zen(text, ignore='', kana=True, ascii=False, digit=False):
+    """An alias of h2z"""
+    return h2z(text, ignore, kana, ascii, digit)
+
+
 def z2h(text, ignore='', kana=True, ascii=False, digit=False):
     """Convert Full-width (Zenkaku) Katakana to Half-width (Hankaku) Katakana
 
@@ -284,6 +301,16 @@ def z2h(text, ignore='', kana=True, ascii=False, digit=False):
     return _convert(text, z2h_map)
 
 
+def zenkaku2hankaku(text, ignore='', kana=True, ascii=False, digit=False):
+    """An alias of z2h"""
+    return z2h(text, ignore, kana, ascii, digit)
+
+
+def zen2han(text, ignore='', kana=True, ascii=False, digit=False):
+    """An alias of z2h"""
+    return z2h(text, ignore, kana, ascii, digit)
+
+
 def normalize(text, mode='NFKC'):
     """Convert Half-width (Hankaku) Katakana to Full-width (Zenkaku) Katakana,
     Full-width (Zenkaku) ASCII and DIGIT to Half-width (Hankaku) ASCII
@@ -294,7 +321,7 @@ def normalize(text, mode='NFKC'):
     ----------
     text : str
         Source string.
-    mode : str, optional
+    mode : Literal['NFC', 'NFD', 'NFKC', 'NFKD'], optional
         Unicode normalization mode.
 
     Return
@@ -308,25 +335,22 @@ def normalize(text, mode='NFKC'):
     ティロ・フィナーレ
     """
     text = text.replace('〜', 'ー').replace('～', 'ー')
-    text = text.replace("’", "'").replace('”', '"').replace('“', '"')
-    text = text.replace('―', '-').replace('‐',
-                                          '-').replace('˗',
-                                                       '-').replace('֊', '-')
-    text = text.replace('‐', '-').replace('‑',
-                                          '-').replace('‒',
-                                                       '-').replace('–', '-')
-    text = text.replace('⁃', '-').replace('⁻',
-                                          '-').replace('₋',
-                                                       '-').replace('−', '-')
-    text = text.replace('﹣', 'ー').replace('－',
-                                          'ー').replace('—',
-                                                       'ー').replace('―', 'ー')
+    text = text.replace('’', "'").replace('”', '"').replace('“', '"')
+    text = text.replace('―', '-').replace('‐', '-').replace('˗', '-').replace('֊', '-')
+    text = text.replace('‐', '-').replace('‑', '-').replace('‒', '-').replace('–', '-')
+    text = text.replace('⁃', '-').replace('⁻', '-').replace('₋', '-').replace('−', '-')
+    text = (
+        text.replace('﹣', 'ー')
+        .replace('－', 'ー')
+        .replace('—', 'ー')
+        .replace('―', 'ー')
+    )
     text = text.replace('━', 'ー').replace('─', 'ー')
-    return unicodedata.normalize(mode, text)
+    return unicodedata.normalize(mode, text)  # pyright: ignore[reportArgumentType]
 
 
 def kana2alphabet(text):
-    """Convert Hiragana to hepburn-style alphabets
+    """Convert Hiragana to Roman-input-style alphabets
 
     Parameters
     ----------
@@ -380,6 +404,14 @@ def kana2alphabet(text):
     text = text.replace('や', 'ya').replace('ゆ', 'yu').replace('よ', 'yo')
     text = text.replace('わ', 'wa').replace('ゐ', 'wi').replace('を', 'wo')
     text = text.replace('ゑ', 'we')
+    text = text.replace('ゔぁ', 'va').replace('ゔぃ', 'vi').replace('ゔぅ', 'vuu')
+    text = text.replace('ゔぇ', 've').replace('ゔぉ', 'vo')
+    text = text.replace('ゃ', 'ya').replace('ゅ', 'yu').replace('ょ', 'yo')
+    text = text.replace('ぁ', 'a').replace('ぃ', 'i').replace('ぅ', 'u')
+    text = text.replace('ぇ', 'e').replace('ぉ', 'o')
+    text = text.replace('ゎ', 'wa')
+    text = text.replace('ゔ', 'vu')
+    text = text.replace('ヵ', 'ka')  # Strictly, it's kanji, not kana.
     text = _convert(text, KANA2HEP)
     while 'っ' in text:
         chars = list(text)
@@ -396,6 +428,27 @@ def kana2alphabet(text):
     return text
 
 
+def kata2alphabet(text):
+    """Convert Katakana to Roman-input-style alphabets
+
+    Parameters
+    ----------
+    text : str
+        Katakana string.
+
+    Return
+    ------
+    str
+        Roman-input-style alphabets string.
+
+    Examples
+    --------
+    >>> print(jaconv.kata2alphabet('マミサン'))
+    mamisan
+    """
+    return kana2alphabet(kata2hira(text))
+
+
 def alphabet2kana(text):
     """Convert alphabets to Hiragana
 
@@ -415,21 +468,29 @@ def alphabet2kana(text):
     まみさん
     """
     text = text.lower()  # ensure lower case.
-  
-    # replace final h with う, e.g., Itoh -> いとう
-    text = re.sub(ending_h_pattern, 'う', text)
 
+    # replace final h with う, e.g., Itoh -> いとう
+    if text.endswith('h') and len(text) >= 2:
+        text = text[:-1] + 'う'
+
+    text = text.replace('tch', 'っch')
+    text = text.replace('bb', 'っb').replace('cc', 'っc').replace('dd', 'っd')
+    text = text.replace('ff', 'っf').replace('gg', 'っg').replace('hh', 'っh')
+    text = text.replace('jj', 'っj').replace('kk', 'っk').replace('ll', 'っl')
+    text = text.replace('mm', 'っm').replace('pp', 'っp').replace('qq', 'っq')
+    text = text.replace('rr', 'っr').replace('ss', 'っs').replace('tt', 'っt')
+    text = text.replace('vv', 'っv').replace('ww', 'っw').replace('xx', 'っx')
+    text = text.replace('yy', 'っy').replace('zz', 'っz')
     text = text.replace('kya', 'きゃ').replace('kyi', 'きぃ').replace('kyu', 'きゅ')
     text = text.replace('kye', 'きぇ').replace('kyo', 'きょ')
     text = text.replace('gya', 'ぎゃ').replace('gyi', 'ぎぃ').replace('gyu', 'ぎゅ')
     text = text.replace('gye', 'ぎぇ').replace('gyo', 'ぎょ')
-    text = text.replace('sha', 'しゃ').replace('shu', 'しゅ').replace('she', 'しぇ')
-    text = text.replace('sho', 'しょ')
+    text = text.replace('sha', 'しゃ').replace('shi', 'し').replace('shu', 'しゅ')
+    text = text.replace('she', 'しぇ').replace('sho', 'しょ')
     text = text.replace('sya', 'しゃ').replace('syi', 'しぃ').replace('syu', 'しゅ')
     text = text.replace('sye', 'しぇ').replace('syo', 'しょ')
     text = text.replace('zya', 'じゃ').replace('zyu', 'じゅ').replace('zyo', 'じょ')
     text = text.replace('zyi', 'じぃ').replace('zye', 'じぇ')
-    text = text.replace('ja', 'じゃ').replace('ju', 'じゅ').replace('jo', 'じょ')
     text = text.replace('jya', 'じゃ').replace('jyi', 'じぃ').replace('jyu', 'じゅ')
     text = text.replace('jye', 'じぇ').replace('jyo', 'じょ')
     text = text.replace('dya', 'ぢゃ').replace('dyi', 'ぢぃ').replace('dyu', 'ぢゅ')
@@ -442,21 +503,25 @@ def alphabet2kana(text):
     text = text.replace('tye', 'ちぇ').replace('tyo', 'ちょ')
     text = text.replace('tsa', 'つぁ').replace('tsi', 'つぃ').replace('tse', 'つぇ')
     text = text.replace('tso', 'つぉ')
-    text = text.replace('thi', 'てぃ').replace('t\'i', 'てぃ')
-    text = text.replace('tha', 'てゃ').replace('thu',
-                                             'てゅ').replace('t\'yu', 'てゅ')
+    text = text.replace('thi', 'てぃ').replace("t'i", 'てぃ')
+    text = text.replace('tha', 'てゃ').replace('thu', 'てゅ').replace("t'yu", 'てゅ')
     text = text.replace('the', 'てぇ').replace('tho', 'てょ')
-    text = text.replace('dha', 'でゃ').replace('dhi', 'でぃ').replace('d\'i', 'でぃ')
+    text = text.replace('dha', 'でゃ').replace('dhi', 'でぃ').replace("d'i", 'でぃ')
     text = text.replace('dhu', 'でゅ').replace('dhe', 'でぇ').replace('dho', 'でょ')
-    text = text.replace('d\'yu', 'でゅ')
+    text = text.replace("d'yu", 'でゅ')
     text = text.replace('twa', 'とぁ').replace('twi', 'とぃ').replace('twu', 'とぅ')
-    text = text.replace('twe', 'とぇ').replace('two', 'とぉ').replace('t\'u', 'とぅ')
+    text = text.replace('twe', 'とぇ').replace('two', 'とぉ').replace("t'u", 'とぅ')
     text = text.replace('dwa', 'どぁ').replace('dwi', 'どぃ').replace('dwu', 'どぅ')
-    text = text.replace('dwe', 'どぇ').replace('dwo', 'どぉ').replace('d\'u', 'どぅ')
+    text = text.replace('dwe', 'どぇ').replace('dwo', 'どぉ').replace("d'u", 'どぅ')
     text = text.replace('nya', 'にゃ').replace('nyi', 'にぃ').replace('nyu', 'にゅ')
     text = text.replace('nye', 'にぇ').replace('nyo', 'にょ')
     text = text.replace('hya', 'ひゃ').replace('hyi', 'ひぃ').replace('hyu', 'ひゅ')
     text = text.replace('hye', 'ひぇ').replace('hyo', 'ひょ')
+    text = text.replace('hwa', 'ふぁ').replace('hwi', 'ふぃ').replace('hwe', 'ふぇ')
+    text = text.replace('hwo', 'ふぉ').replace('hwyu', 'ふゅ')
+    text = text.replace('fya', 'ふゃ').replace('fyu', 'ふゅ').replace('fyo', 'ふょ')
+    text = text.replace('pha', 'ふぁ').replace('phi', 'ふぃ').replace('phu', 'ふぅ')
+    text = text.replace('phe', 'ふぇ').replace('pho', 'ふぉ')
     text = text.replace('mya', 'みゃ').replace('myi', 'みぃ').replace('myu', 'みゅ')
     text = text.replace('mye', 'みぇ').replace('myo', 'みょ')
     text = text.replace('rya', 'りゃ').replace('ryi', 'りぃ').replace('ryu', 'りゅ')
@@ -467,20 +532,7 @@ def alphabet2kana(text):
     text = text.replace('pye', 'ぴぇ').replace('pyo', 'ぴょ')
     text = text.replace('vyi', 'ゔぃ').replace('vyu', 'ゔゅ').replace('vye', 'ゔぇ')
     text = text.replace('vyo', 'ゔょ')
-    text = text.replace('fya', 'ふゃ').replace('fyu', 'ふゅ').replace('fyo', 'ふょ')
-    text = text.replace('hwa', 'ふぁ').replace('hwi', 'ふぃ').replace('hwe', 'ふぇ')
-    text = text.replace('hwo', 'ふぉ').replace('hwyu', 'ふゅ')
-    text = text.replace('pha', 'ふぁ').replace('phi', 'ふぃ').replace('phu', 'ふぅ')
-    text = text.replace('phe', 'ふぇ').replace('pho', 'ふぉ')
-    text = text.replace('xn', 'ん').replace('xa', 'ぁ').replace('xi', 'ぃ')
-    text = text.replace('xu', 'ぅ').replace('xe', 'ぇ').replace('xo', 'ぉ')
-    text = text.replace('lyi', 'ぃ').replace('xyi', 'ぃ').replace('lye', 'ぇ')
-    text = text.replace('xye', 'ぇ').replace('xka', 'ヵ').replace('xke', 'ヶ')
-    text = text.replace('lka', 'ヵ').replace('lke', 'ヶ')
-    text = text.replace('ca', 'か').replace('ci', 'し').replace('cu', 'く')
-    text = text.replace('co', 'こ')
-    text = text.replace('qa', 'くぁ').replace('qi', 'くぃ').replace('qu', 'く')
-    text = text.replace('qe', 'くぇ').replace('qo', 'くぉ')
+    text = text.replace('wye', 'ゑ')
     text = text.replace('kwa', 'くぁ').replace('kwi', 'くぃ').replace('kwu', 'くぅ')
     text = text.replace('kwe', 'くぇ').replace('kwo', 'くぉ')
     text = text.replace('gwa', 'ぐぁ').replace('gwi', 'ぐぃ').replace('gwu', 'ぐぅ')
@@ -489,8 +541,7 @@ def alphabet2kana(text):
     text = text.replace('swe', 'すぇ').replace('swo', 'すぉ')
     text = text.replace('zwa', 'ずぁ').replace('zwi', 'ずぃ').replace('zwu', 'ずぅ')
     text = text.replace('zwe', 'ずぇ').replace('zwo', 'ずぉ')
-    text = text.replace('je', 'じぇ')
-    text = text.replace('ti', 'ち')
+    text = text.replace('vya', 'ゔゃ')
     text = text.replace('xtu', 'っ').replace('xtsu', 'っ')
     text = text.replace('ltu', 'っ').replace('ltsu', 'っ')
     text = text.replace('xya', 'ゃ').replace('lya', 'ゃ')
@@ -499,52 +550,86 @@ def alphabet2kana(text):
     text = text.replace('wha', 'うぁ').replace('whi', 'うぃ').replace('whu', 'う')
     text = text.replace('whe', 'うぇ').replace('who', 'うぉ')
     text = text.replace('xwa', 'ゎ').replace('lwa', 'ゎ')
+    text = text.replace('lyi', 'ぃ').replace('xyi', 'ぃ')
+    text = text.replace('lye', 'ぇ').replace('xye', 'ぇ')
+    text = text.replace('xka', 'ヵ').replace('lka', 'ヵ')
+    text = text.replace('xke', 'ヶ').replace('lke', 'ヶ')
     text = text.replace('tsu', 'つ')
+    text = text.replace('nn', 'ん')
+    text = text.replace('ja', 'じゃ').replace('ji', 'じ').replace('ju', 'じゅ')
+    text = text.replace('je', 'じぇ').replace('jo', 'じょ')
     text = text.replace('ga', 'が').replace('gi', 'ぎ').replace('gu', 'ぐ')
     text = text.replace('ge', 'げ').replace('go', 'ご')
-    text = text.replace('za', 'ざ').replace('ji', 'じ').replace('zi', 'じ')
-    text = text.replace('zu', 'ず').replace('ze', 'ぜ').replace('zo', 'ぞ')
-    text = text.replace('da', 'だ').replace('di', 'ぢ')
-    text = text.replace('zu', 'づ').replace('du', 'づ')
+    text = text.replace('za', 'ざ').replace('zi', 'じ').replace('zu', 'ず')
+    text = text.replace('ze', 'ぜ').replace('zo', 'ぞ')
+    text = text.replace('da', 'だ').replace('di', 'ぢ').replace('du', 'づ')
     text = text.replace('de', 'で').replace('do', 'ど')
     text = text.replace('va', 'ゔぁ').replace('vi', 'ゔぃ').replace('vu', 'ゔ')
-    text = text.replace('ve', 'ゔぇ').replace('vo', 'ゔぉ').replace('vya', 'ゔゃ')
+    text = text.replace('ve', 'ゔぇ').replace('vo', 'ゔぉ')
     text = text.replace('ba', 'ば').replace('bi', 'び').replace('bu', 'ぶ')
-    text = text.replace('be', 'べ').replace('bo', 'ぼ').replace('pa', 'ぱ')
-    text = text.replace('pi', 'ぴ').replace('pu', 'ぷ').replace('pe', 'ぺ')
-    text = text.replace('po', 'ぽ')
+    text = text.replace('be', 'べ').replace('bo', 'ぼ')
+    text = text.replace('pa', 'ぱ').replace('pi', 'ぴ').replace('pu', 'ぷ')
+    text = text.replace('pe', 'ぺ').replace('po', 'ぽ')
     text = text.replace('ka', 'か').replace('ki', 'き').replace('ku', 'く')
-    text = text.replace('ke', 'け').replace('ko', 'こ').replace('sa', 'さ')
-    text = text.replace('shi', 'し').replace('su', 'す').replace('se', 'せ')
-    text = text.replace('so', 'そ').replace('ta', 'た').replace('chi', 'ち')
-    text = text.replace('te', 'て').replace('to', 'と')
+    text = text.replace('ke', 'け').replace('ko', 'こ')
+    text = text.replace('qa', 'くぁ').replace('qi', 'くぃ').replace('qu', 'く')
+    text = text.replace('qe', 'くぇ').replace('qo', 'くぉ')
+    text = text.replace('ca', 'か').replace('cu', 'く').replace('co', 'こ')
+    text = text.replace('ci', 'し').replace('ce', 'せ')
+    text = text.replace('sa', 'さ').replace('si', 'し').replace('su', 'す')
+    text = text.replace('se', 'せ').replace('so', 'そ')
+    text = text.replace('ta', 'た').replace('chi', 'ち').replace('ti', 'ち')
+    text = text.replace('tu', 'つ').replace('te', 'て').replace('to', 'と')
     text = text.replace('na', 'な').replace('ni', 'に').replace('nu', 'ぬ')
-    text = text.replace('ne', 'ね').replace('no', 'の').replace('ha', 'は')
-    text = text.replace('hi', 'ひ').replace('fu', 'ふ').replace('he', 'へ')
-    text = text.replace('ho', 'ほ').replace('ma', 'ま').replace('mi', 'み')
-    text = text.replace('mu', 'む').replace('me', 'め').replace('mo', 'も')
+    text = text.replace('ne', 'ね').replace('no', 'の')
+    text = text.replace('ha', 'は').replace('hi', 'ひ').replace('fu', 'ふ')
+    text = text.replace('hu', 'ふ').replace('he', 'へ').replace('ho', 'ほ')
+    text = text.replace('fa', 'ふぁ').replace('fi', 'ふぃ').replace('fe', 'ふぇ')
+    text = text.replace('fo', 'ふぉ')
+    text = text.replace('ma', 'ま').replace('mi', 'み').replace('mu', 'む')
+    text = text.replace('me', 'め').replace('mo', 'も')
     text = text.replace('ra', 'ら').replace('ri', 'り').replace('ru', 'る')
     text = text.replace('re', 'れ').replace('ro', 'ろ')
     text = text.replace('la', 'ら').replace('li', 'り').replace('lu', 'る')
     text = text.replace('le', 'れ').replace('lo', 'ろ')
     text = text.replace('ya', 'や').replace('yu', 'ゆ').replace('yo', 'よ')
-    text = text.replace('wa', 'わ').replace('wyi', 'ゐ').replace('wu', 'う')
-    text = text.replace('wye', 'ゑ')
-    text = text.replace('wo', 'を')
-    text = text.replace('nn', 'ん').replace('m', 'ん')
-    text = text.replace('tu', 'つ').replace('hu', 'ふ')
-    text = text.replace('fa', 'ふぁ').replace('fi', 'ふぃ').replace('fe', 'ふぇ')
-    text = text.replace('fo', 'ふぉ').replace('oh', 'おお')
-    text = text.replace('l', 'る').replace('-', 'ー')
+    text = text.replace('ye', 'いぇ')
+    text = text.replace('wa', 'わ').replace('wi', 'うぃ').replace('wyi', 'ゐ')
+    text = text.replace('wu', 'う').replace('wo', 'を')
+    text = text.replace('oh', 'おお')
+    text = text.replace('xa', 'ぁ').replace('xi', 'ぃ').replace('xu', 'ぅ')
+    text = text.replace('xe', 'ぇ').replace('xo', 'ぉ')
+    text = text.replace("n'", 'ん').replace('xn', 'ん').replace('m', 'ん')
     text = _convert(text, HEP2KANA)
     ret = []
-    for (i, char) in enumerate(text):
+    for i, char in enumerate(text):
         if char in consonants:
             char = 'っ'
         ret.append(char)
     return ''.join(ret)
 
 
+def alphabet2kata(text):
+    """Convert alphabets to Katakana
+
+    Parameters
+    ----------
+    text : str
+        Roman-input-style alphabets string.
+
+    Return
+    ------
+    str
+        Katakana string.
+
+    Examples
+    --------
+    >>> print(jaconv.alphabet2kata('mamisan'))
+    マミサン
+    """
+    return hira2kata(alphabet2kana(text))
+
+
 def hiragana2julius(text):
     """Convert Hiragana to Julius's phoneme format.
 
@@ -854,10 +939,9 @@ def hiragana2julius(text):
     text = text.replace('ぇ', ' e')
     text = text.replace('ぉ', ' o')
     text = text.replace('ゎ', ' w a')
-    text = text.replace('ぉ', ' o')
 
     # 長音の処理
-    for (pattern, replace_str) in JULIUS_LONG_VOWEL:
+    for pattern, replace_str in JULIUS_LONG_VOWEL:
         text = pattern.sub(replace_str, text)
     text = text.replace('o u', 'o:')  # おう -> おーの音便
     text = text.replace('ー', ':')
@@ -865,7 +949,7 @@ def hiragana2julius(text):
     text = text.replace('−', ':')
     text = text.replace('-', ':')
 
-    #その他特別な処理
+    # その他特別な処理
     text = text.replace('を', ' o')
 
     text = text.strip()
